==> eg_particle_interactions-v0.8-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/ParticleInteractionsMod.java <==
package games.enchanted.eg_particle_interactions.common;

import games.enchanted.eg_particle_interactions.common.config.ConfigHandler;
import games.enchanted.eg_particle_interactions.common.particle_override.BlockParticleOverrides;
import games.enchanted.eg_particle_interactions.common.resource.ParticlePaletteAtlasManager;
import it.unimi.dsi.fastutil.Pair;
import java.util.List;
import net.minecraft.class_1060;
import net.minecraft.class_2960;
import net.minecraft.class_3302;
import net.minecraft.class_3304;

/**
 * This is the entry point for your mod's common side, called by each modloader specific side.
 */
public class ParticleInteractionsMod {
    public static ParticlePaletteAtlasManager particlePaletteAtlas;

    public static void startOfModLoading() {
        Logging.info("Mod is loading on a {} environment!", Constants.TARGET_PLATFORM);
    }

    public static void endOfModLoading() {
        ConfigHandler.load();
        ConfigHandler.save();
        BlockParticleOverrides.registerOverrides();
        Logging.info("Loaded Successfully!");
    }

    public static void registerAtlases(class_3304 resourceManager, class_1060 textureManager) {
        List<Pair<class_2960, class_3302>> reloadListeners = createReloadListeners(textureManager);
        //? if fabric {
        reloadListeners.forEach(resourceLocationAndReloadListenerPair -> {
            resourceManager.method_14477(resourceLocationAndReloadListenerPair.value());
        });
        //?}
    }

    public static List<Pair<class_2960, class_3302>> createReloadListeners(class_1060 textureManager) {
        particlePaletteAtlas = new ParticlePaletteAtlasManager(textureManager);
        return List.of(Pair.of(ParticlePaletteAtlasManager.ATLAS_LOCATION, particlePaletteAtlas));
    }
}

==> eg_particle_interactions-v0.8.3-fabric-mc1.21.10-sources.jar: games/enchanted/eg_particle_interactions/common/ParticleInteractionsMod.java <==
package games.enchanted.eg_particle_interactions.common;

import games.enchanted.eg_particle_interactions.common.config.ConfigHandler;
import games.enchanted.eg_particle_interactions.common.particle_override.BlockParticleOverrides;
import games.enchanted.eg_particle_interactions.common.resource.ParticlePaletteAtlasManager;
import it.unimi.dsi.fastutil.Pair;
import java.util.List;
import net.minecraft.class_1060;
import net.minecraft.class_2960;
import net.minecraft.class_3302;
import net.minecraft.class_3304;

/**
 * This is the entry point for your mod's common side, called by each modloader specific side.
 */
public class ParticleInteractionsMod {
    //? if minecraft: > 1.21.8 {
    @Deprecated
    //?}
    public static ParticlePaletteAtlasManager particlePaletteAtlas;

    public static void startOfModLoading() {
        Logging.info("Mod is loading on a {} environment!", Constants.TARGET_PLATFORM);
    }

    public static void endOfModLoading() {
        ConfigHandler.load();
        ConfigHandler.save();
        BlockParticleOverrides.registerOverrides();
        Logging.info("Loaded Successfully!");
    }

    public static void registerAtlases(class_3304 resourceManager, class_1060 textureManager) {
        List<Pair<class_2960, class_3302>> reloadListeners = createReloadListeners(textureManager);
        //? if fabric {
        reloadListeners.forEach(resourceLocationAndReloadListenerPair -> {
            resourceManager.method_14477(resourceLocationAndReloadListenerPair.value());
        });
        //?}
    }

    public static List<Pair<class_2960, class_3302>> createReloadListeners(class_1060 textureManager) {
        //? if minecraft: <= 1.21.8 {
        /*particlePaletteAtlas = new ParticlePaletteAtlasManager(textureManager);
        return List.of(Pair.of(ParticlePaletteAtlasManager.ATLAS_LOCATION, particlePaletteAtlas));
        *///?} else {
        return List.of();
        //?}
    }
}
